gleamtea/filepicker
A bubble: a filesystem picker.
Types
An opaque file-picker value.
pub type FilePicker
Values
pub fn did_select_file(picker: FilePicker) -> Result(String, Nil)
The path of a file the user just selected, or Error(Nil).
pub fn new(height height: Int) -> FilePicker
A file picker showing height visible entries, starting in the current
working directory.
pub fn update(
msg: msg,
picker: FilePicker,
) -> #(FilePicker, gleamtea.Cmd(msg))
Navigate in response to a key.
pub fn view(picker: FilePicker) -> String
Render the current path and the visible window of entries.